Lifeforms
=========

.. automodule:: seagull.lifeforms 

Base
----

.. automodule:: seagull.lifeforms.base
   :members:
   :undoc-members:
   :special-members: __init__


Custom
------

.. automodule:: seagull.lifeforms.custom
   :members:
   :undoc-members:
   :special-members: __init__

All Lifeforms
-------------

This section contains all lifeforms currently implemented in the library.
It is not yet comprehensive, so it would be really nice if you can help me add
more!


Gliders
~~~~~~~

.. automodule:: seagull.lifeforms.gliders
.. autosummary::
   seagull.lifeforms.gliders.Glider

Growers
~~~~~~~

.. automodule:: seagull.lifeforms.growers
.. autosummary::
   seagull.lifeforms.growers.Unbounded
   

Oscillators
~~~~~~~~~~~

.. automodule:: seagull.lifeforms.oscillators
.. autosummary::
   seagull.lifeforms.oscillators.Blinker
   seagull.lifeforms.oscillators.Toad
   seagull.lifeforms.oscillators.Pulsar

Random
~~~~~~

.. automodule:: seagull.lifeforms.random
.. autosummary::
   seagull.lifeforms.random.RandomBox

Static
~~~~~~

.. automodule:: seagull.lifeforms.static
.. autosummary::
   seagull.lifeforms.static.Box
   seagull.lifeforms.static.Seed
   seagull.lifeforms.static.Moon
   seagull.lifeforms.static.Kite


